# mypy-boto3-waf

[![PyPI - mypy-boto3-waf](https://img.shields.io/pypi/v/mypy-boto3-waf.svg?color=blue)](https://pypi.org/project/mypy-boto3-waf)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-waf.svg?color=blue)](https://pypi.org/project/mypy-boto3-waf)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

- [mypy-boto3-waf](#mypy-boto3-waf)
  - [How to use](#how-to-use)
  - [Automated type discovery](#automated-type-discovery)


Type annotations for
[boto3.WAF 1.13.26](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/waf.html#WAF) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.0.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-waf](#mypy-boto3-waf)
  - [How to use](#how-to-use)
    - [Type checking](#type-checking)
  - [How it works](#how-it-works)

## How to use

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `WAF` service.

```bash
python -m pip install boto3-stubs[waf]

# update installed packages index for automated type discovery
python -m mypy_boto3
```

Use `boto3` with `mypy_boto3_waf` in your project and enjoy type checking and auto-complete.

```python
import boto3

from mypy_boto3_waf import WAFClient

# Now mypy can check if your code is valid.
client: WAFClient = boto3.client("waf")

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: WAFClient = session.client("waf")



# Annotated paginators are included as well

import mypy_boto3_waf.paginator as waf_paginators

get_rate_based_rule_managed_keys_paginator: waf_paginators.GetRateBasedRuleManagedKeysPaginator = client.get_paginator("get_rate_based_rule_managed_keys")
list_activated_rules_in_rule_group_paginator: waf_paginators.ListActivatedRulesInRuleGroupPaginator = client.get_paginator("list_activated_rules_in_rule_group")
list_byte_match_sets_paginator: waf_paginators.ListByteMatchSetsPaginator = client.get_paginator("list_byte_match_sets")
list_geo_match_sets_paginator: waf_paginators.ListGeoMatchSetsPaginator = client.get_paginator("list_geo_match_sets")
list_ip_sets_paginator: waf_paginators.ListIPSetsPaginator = client.get_paginator("list_ip_sets")
list_logging_configurations_paginator: waf_paginators.ListLoggingConfigurationsPaginator = client.get_paginator("list_logging_configurations")
list_rate_based_rules_paginator: waf_paginators.ListRateBasedRulesPaginator = client.get_paginator("list_rate_based_rules")
list_regex_match_sets_paginator: waf_paginators.ListRegexMatchSetsPaginator = client.get_paginator("list_regex_match_sets")
list_regex_pattern_sets_paginator: waf_paginators.ListRegexPatternSetsPaginator = client.get_paginator("list_regex_pattern_sets")
list_rule_groups_paginator: waf_paginators.ListRuleGroupsPaginator = client.get_paginator("list_rule_groups")
list_rules_paginator: waf_paginators.ListRulesPaginator = client.get_paginator("list_rules")
list_size_constraint_sets_paginator: waf_paginators.ListSizeConstraintSetsPaginator = client.get_paginator("list_size_constraint_sets")
list_sql_injection_match_sets_paginator: waf_paginators.ListSqlInjectionMatchSetsPaginator = client.get_paginator("list_sql_injection_match_sets")
list_subscribed_rule_groups_paginator: waf_paginators.ListSubscribedRuleGroupsPaginator = client.get_paginator("list_subscribed_rule_groups")
list_web_acls_paginator: waf_paginators.ListWebACLsPaginator = client.get_paginator("list_web_acls")
list_xss_match_sets_paginator: waf_paginators.ListXssMatchSetsPaginator = client.get_paginator("list_xss_match_sets")
```

## Automated type discovery

`mypy_boto3` package can generate index for `mypy_boto3_waf` and other installed services.

```bash
# Run this command when you add or remove service packages
python -m mypy_boto3
```

Generated index provides overloads for `boto3.client` and `boto3.service`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully
- `VSCode` does not currently support function overloads

Also, generated index allows you to import types from `mypy_boto3`:

```python
# you can replace imports
import mypy_boto3_waf as waf
from mypy_boto3_waf import WAFClient

# with these
from mypy_boto3 import waf
from mypy_boto3.waf import WAFClient
```